@@ -187,7 +187,12 @@ struct DeqpConfig {
 }
 
 impl DeqpConfig {
-    fn deqp(&self, output_dir: &Path, qpa_to_xml: Option<PathBuf>) -> Result<DeqpCommand> {
+    fn deqp(
+        &self,
+        output_dir: &Path,
+        qpa_to_xml: Option<PathBuf>,
+        save_xfail_logs: bool,
+    ) -> Result<DeqpCommand> {
         Ok(DeqpCommand {
             deqp: self.deqp.clone(),
             args: self.deqp_args.clone(),
@@ -198,6 +203,7 @@ impl DeqpConfig {
                 baseline: read_baseline(self.baseline.as_ref())?,
                 timeout: Duration::from_secs_f32(self.timeout),
                 env: self.env.clone(),
+                save_xfail_logs,
             },
             qpa_to_xml,
             prefix: self.prefix.to_owned(),
@@ -320,8 +326,6 @@ struct SuiteConfig {
 }
 
 fn main() -> Result<()> {
-    stderrlog::new().module(module_path!()).init().unwrap();
-
     let opts = Opts::from_args();
 
     match opts.subcmd {
@@ -346,7 +350,11 @@ fn main() -> Result<()> {
                 renderer_check: run.renderer_check,
                 version_check: run.version_check,
             };
-            let deqp = config.deqp(&run.common.output_dir, run.testlog_to_xml)?;
+            let deqp = config.deqp(
+                &run.common.output_dir,
+                run.testlog_to_xml,
+                run.common.save_xfail_logs,
+            )?;
 
             let results = parallel_test(std::io::stdout(), config.test_groups(&deqp, &[])?)?;
             process_results(&results, &run.common.output_dir, run.common.summary_limit)?;
@@ -407,7 +415,11 @@ fn main() -> Result<()> {
 
             let mut deqp = Vec::new();
             for config in &configs {
-                deqp.push(config.deqp(&suite.common.output_dir, suite.testlog_to_xml.clone())?);
+                deqp.push(config.deqp(
+                    &suite.common.output_dir,
+                    suite.testlog_to_xml.clone(),
+                    suite.common.save_xfail_logs,
+                )?);
             }
 
             let mut test_groups = Vec::new();
@@ -425,6 +437,8 @@ fn main() -> Result<()> {
         }
 
         SubCommand::Junit(junit) => {
+            stderrlog::new().module(module_path!()).init().unwrap();
+
             let results = RunnerResults::from_csv(&mut File::open(&junit.results)?)
                 .context("Reading in results csv")?;
 
@@ -435,6 +449,8 @@ fn main() -> Result<()> {
         }
 
         SubCommand::MockDeqp(mock) => {
+            stderrlog::new().module(module_path!()).init().unwrap();
+
             mock_deqp(&mock)?;
         }
     }
