@@ -113,10 +113,33 @@ pub struct CommandLineRunOptions {
         help = "Number of fails or flakes to print in the summary line (0 = no limit)"
     )]
     pub summary_limit: usize,
+
+    #[structopt(
+        parse(from_occurrences),
+        short = "v",
+        long,
+        help = "Enable verbose mode (-v, -vv, -vvv, etc)"
+    )]
+    pub verbose: usize,
+
+    #[structopt(long, help = "Enable log timestamps (sec, ms, ns)")]
+    pub timestamp: Option<stderrlog::Timestamp>,
+    #[structopt(
+        long,
+        help = "Saves log files for expected failures along with new ones"
+    )]
+    pub save_xfail_logs: bool,
 }
 
 impl CommandLineRunOptions {
     pub fn setup(&self) -> Result<()> {
+        stderrlog::new()
+            .module(module_path!())
+            .verbosity(self.verbose)
+            .timestamp(self.timestamp.unwrap_or(stderrlog::Timestamp::Off))
+            .init()
+            .unwrap();
+
         if self.jobs > 0 {
             rayon::ThreadPoolBuilder::new()
                 .num_threads(self.jobs)
@@ -166,6 +189,7 @@ pub struct TestConfiguration {
     pub baseline: RunnerResults,
     pub timeout: Duration,
     pub env: HashMap<String, String>,
+    pub save_xfail_logs: bool,
 }
 
 pub trait TestCommand {
