@@ -15,20 +15,15 @@ struct HMSDuration(Duration);
 impl fmt::Display for HMSDuration {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         let mut secs = self.0.as_secs();
-        let mut has_hours = false;
-        if secs >= 3600 {
-            write!(f, "{}:", secs / 3600)?;
-            secs %= 3600;
-            has_hours = true;
-        }
-        if secs >= 60 {
-            if has_hours {
-                write!(f, "{:02}:", secs / 60)?;
-            } else {
-                write!(f, "{}:", secs / 60)?;
-            }
-            secs %= 60;
-            write!(f, "{:02}", secs)
+        let hours = secs / 3600;
+        secs %= 3600;
+        let mins = secs / 60;
+        secs %= 60;
+
+        if hours > 0 {
+            write!(f, "{}:{:02}:{:02}", hours, mins, secs)
+        } else if mins > 0 {
+            write!(f, "{}:{:02}", mins, secs)
         } else {
             write!(f, "{}", secs)
         }
@@ -86,8 +81,10 @@ impl RunnerStatus {
         }
     }
 
-    pub fn should_save_logs(&self) -> bool {
-        !self.is_success() || *self == RunnerStatus::Flake
+    pub fn should_save_logs(&self, save_xfail_logs: bool) -> bool {
+        !self.is_success()
+            || *self == RunnerStatus::Flake
+            || (*self == RunnerStatus::ExpectedFail && save_xfail_logs)
     }
 
     pub fn from_deqp(status: DeqpStatus) -> RunnerStatus {
@@ -651,6 +648,10 @@ dEQP-GLES2.info.version,Pass"
         assert_eq!(format!("{}", HMSDuration(Duration::new(0, 20))), "0");
         assert_eq!(format!("{}", HMSDuration(Duration::new(70, 20))), "1:10");
         assert_eq!(format!("{}", HMSDuration(Duration::new(69, 20))), "1:09");
+        assert_eq!(
+            format!("{}", HMSDuration(Duration::new(60 * 60 + 3, 20))),
+            "1:00:03"
+        );
         assert_eq!(
             format!("{}", HMSDuration(Duration::new(3735, 20))),
             "1:02:15"
