@@ -6,9 +6,9 @@ use std::process::{Command, Stdio};
 /// Builder for a mocked piglit-runner invocation
 #[derive(Default)]
 struct PiglitMock {
-    baseline: Vec<String>,
-    skips: Vec<String>,
-    flakes: Vec<String>,
+    baselines: Vec<tempfile::TempPath>,
+    skips: Vec<tempfile::TempPath>,
+    flakes: Vec<tempfile::TempPath>,
     runner_args: Vec<String>,
 }
 
@@ -68,41 +68,20 @@ impl PiglitMock {
         let child = child.arg("--timeout");
         let child = child.arg("1");
 
-        #[allow(unused_variables)]
-        let baseline_file = if !self.baseline.is_empty() {
-            let baseline_file = lines_tempfile(&self.baseline).context("baseline file")?;
-
+        for baseline_file in &self.baselines {
             child.arg("--baseline");
             child.arg(&baseline_file);
+        }
 
-            Some(baseline_file)
-        } else {
-            None
-        };
-
-        #[allow(unused_variables)]
-        let skips_file = if !self.skips.is_empty() {
-            let skips_file = lines_tempfile(&self.skips).context("skips file")?;
-
+        for skips_file in &self.skips {
             child.arg("--skips");
             child.arg(&skips_file);
+        }
 
-            Some(skips_file)
-        } else {
-            None
-        };
-
-        #[allow(unused_variables)]
-        let flakes_file = if !self.flakes.is_empty() {
-            let flakes_file = lines_tempfile(&self.flakes).context("flakes file")?;
-
+        for flakes_file in &self.flakes {
             child.arg("--flakes");
             child.arg(&flakes_file);
-
-            Some(flakes_file)
-        } else {
-            None
-        };
+        }
 
         for arg in &self.runner_args {
             child.arg(arg);
@@ -136,8 +115,9 @@ impl PiglitMock {
         })
     }
 
-    pub fn with_baseline(&mut self, line: &str) -> &mut PiglitMock {
-        self.baseline.push(line.into());
+    pub fn with_baseline<S: AsRef<str>>(&mut self, data: S) -> &mut PiglitMock {
+        self.baselines
+            .push(tempfile(data).context("writing baselines").unwrap());
         self
     }
 
@@ -252,8 +232,11 @@ fn subtest_statuses() {
 #[test]
 fn subtest_baseline() {
     let result = PiglitMock::new()
-        .with_baseline("piglit@subtest_statuses@f,Fail")
-        .with_baseline("piglit@subtest_statuses,Fail")
+        .with_baseline(
+            "
+piglit@subtest_statuses@f,Fail
+piglit@subtest_statuses,Fail",
+        )
         .run(vec!["piglit@subtest_statuses"])
         .unwrap();
     assert!(!result.stderr.contains("piglit@subtest_statuses@p"));
@@ -287,8 +270,11 @@ fn subtest_dupe() {
 #[test]
 fn subtest_commas() {
     let result = PiglitMock::new()
-        .with_baseline("piglit@subtest_commas@GL_INTENSITY16- swizzled- border color only,Fail")
-        .with_baseline("piglit@subtest_commas,Fail")
+        .with_baseline(
+            "
+piglit@subtest_commas@GL_INTENSITY16- swizzled- border color only,Fail
+piglit@subtest_commas,Fail",
+        )
         .run(vec!["piglit@subtest_commas"])
         .unwrap();
     assert!(result
